summaryrefslogtreecommitdiffstats
path: root/chrome/browser/jumplist_win.h
diff options
context:
space:
mode:
authorerg@google.com <erg@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-02 18:35:06 +0000
committererg@google.com <erg@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-02 18:35:06 +0000
commit92926d9fd44a3aa9473afd15ce8b5c6f7f7d192c (patch)
tree419b2a4640e48dfbe0880abcd50d8230849c561e /chrome/browser/jumplist_win.h
parent23b0a94cb3cdf3154e05efb68ad21225859f451a (diff)
downloadchromium_src-92926d9fd44a3aa9473afd15ce8b5c6f7f7d192c.zip
chromium_src-92926d9fd44a3aa9473afd15ce8b5c6f7f7d192c.tar.gz
chromium_src-92926d9fd44a3aa9473afd15ce8b5c6f7f7d192c.tar.bz2
FBTF: Reaplly the TabRestoreService::Observer into its own file commit.
This means browser.h no longer includes a large chunk of the tab restore system. Now with fixes to chromeos. BUG=none TEST=compiles First Review URL: http://codereview.chromium.org/3296003 Review URL: http://codereview.chromium.org/3358005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@58382 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/jumplist_win.h')
-rw-r--r--chrome/browser/jumplist_win.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/jumplist_win.h b/chrome/browser/jumplist_win.h
index e85735d..58146d0 100644
--- a/chrome/browser/jumplist_win.h
+++ b/chrome/browser/jumplist_win.h
@@ -15,6 +15,7 @@
#include "chrome/browser/cancelable_request.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/sessions/tab_restore_service.h"
+#include "chrome/browser/sessions/tab_restore_service_observer.h"
class FilePath;
class Profile;
@@ -91,7 +92,7 @@ typedef std::vector<scoped_refptr<ShellLinkItem> > ShellLinkItemList;
// * Creatng COM objects used by JumpList from PageUsageData objects;
// * Adding COM objects to JumpList, etc.
//
// This class also implements TabRestoreService::Observer. So, once we call
// AddObserver() and register this class as an observer, it automatically
// updates a JumpList when a tab is added or removed.
//
@@ -99,7 +100,7 @@ typedef std::vector<scoped_refptr<ShellLinkItem> > ShellLinkItemList;
// update it in a UI thread. To solve this problem, this class posts a
// task when it actually updates a JumpList. (This task is implemented in an
// anomynous namespace in "jumplist_win.cc".)
-class JumpList : public TabRestoreService::Observer {
+class JumpList : public TabRestoreServiceObserver {
public:
JumpList();
~JumpList();
@@ -91,7 +92,7 @@ typedef std::vector<scoped_refptr<ShellLinkItem> > ShellLinkItemList;
// * Adding COM objects to JumpList, etc.
//
-// This class also implements TabRestoreService::Observer. So, once we call
+// This class also implements TabRestoreServiceObserver. So, once we call
// AddObserver() and register this class as an observer, it automatically
// updates a JumpList when a tab is added or removed.